@@ -19,6 +19,7 @@
 module XMonad.Layout.Renamed ( -- * Usage
                                -- $usage
                                renamed
+                             , named
                              , Rename(..) ) where
 
 import XMonad
@@ -29,7 +30,7 @@ import XMonad.Layout.LayoutModifier
 --
 -- > import XMonad.Layout.Renamed
 --
--- to your @~\/.xmonad\/xmonad.hs@.
+-- to your @xmonad.hs@.
 --
 -- You can then use 'renamed' to modify the description of your
 -- layouts. For example:
@@ -40,6 +41,10 @@ import XMonad.Layout.LayoutModifier
 renamed :: [Rename a] -> l a -> ModifiedLayout Rename l a
 renamed = ModifiedLayout . Chain
 
+-- | Rename a layout. (Convenience alias for @renamed [Replace s]@.)
+named :: String -> l a -> ModifiedLayout Rename l a
+named s = renamed [Replace s]
+
 -- | The available renaming operations
 data Rename a = CutLeft Int -- ^ Remove a number of characters from the left
               | CutRight Int -- ^ Remove a number of characters from the right
