@@ -1,6 +1,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Util.WorkspaceCompare
+-- Description :  Functions for examining, comparing, and sorting workspaces.
 -- Copyright   :  (c) Spencer Janssen <spencerjanssen@gmail.com>
 -- License     :  BSD3-style (see LICENSE)
 --
@@ -11,6 +12,7 @@
 -----------------------------------------------------------------------------
 
 module XMonad.Util.WorkspaceCompare ( WorkspaceCompare, WorkspaceSort
+                                    , filterOutWs
                                     , getWsIndex
                                     , getWsCompare
                                     , getWsCompareByTag
@@ -24,15 +26,19 @@ module XMonad.Util.WorkspaceCompare ( WorkspaceCompare, WorkspaceSort
 
 import XMonad
 import qualified XMonad.StackSet as S
-import Data.List
-import Data.Maybe
-import Data.Monoid (mconcat)
+import XMonad.Prelude
 import XMonad.Actions.PhysicalScreens (ScreenComparator(ScreenComparator), getScreenIdAndRectangle, screenComparatorById)
-import Data.Function (on)
 
 type WorkspaceCompare = WorkspaceId -> WorkspaceId -> Ordering
 type WorkspaceSort = [WindowSpace] -> [WindowSpace]
 
+-- | Transforms a workspace list by filtering out the workspaces that
+-- correspond to the given 'tag's.  Intended for use with 'logHook's (see
+-- 'XMonad.Hooks.StatusBar.PP.filterOutWsPP') and "XMonad.Hooks.EwmhDesktops"
+-- (see 'XMonad.Hooks.EwmhDesktops.addEwmhWorkspaceSort').
+filterOutWs :: [WorkspaceId] -> WorkspaceSort
+filterOutWs ws = filter (\S.Workspace{ S.tag = tag } -> tag `notElem` ws)
+
 -- | Lookup the index of a workspace id in the user's config, return Nothing
 -- if that workspace does not exist in the config.
 getWsIndex :: X (WorkspaceId -> Maybe Int)
@@ -62,7 +68,7 @@ getWsCompareByTag = return compare
 
 -- | A comparison function for Xinerama based on visibility, workspace
 --   and screen id. It produces the same ordering as
---   'XMonad.Hooks.DynamicLog.pprWindowSetXinerama'.
+--   'XMonad.Hooks.StatusBar.PP.pprWindowSetXinerama'.
 getXineramaWsCompare :: X WorkspaceCompare
 getXineramaWsCompare = getXineramaPhysicalWsCompare $ screenComparatorById compare
 
@@ -98,7 +104,7 @@ getSortByTag :: X WorkspaceSort
 getSortByTag = mkWsSort getWsCompareByTag
 
 -- | Sort serveral workspaces for xinerama displays, in the same order
---   produced by 'XMonad.Hooks.DynamicLog.pprWindowSetXinerama': first
+--   produced by 'XMonad.Hooks.StatusBar.PP.pprWindowSetXinerama': first
 --   visible workspaces, sorted by screen, then hidden workspaces,
 --   sorted by tag.
 getSortByXineramaRule :: X WorkspaceSort
